# ==============================================================================================
# NAME: CreateObject_AdoCOM.ps1
# 
# AUTHOR: ed wilson , Microsoft 
# DATE  : 9/19/2008
# 
# COMMENT: Queries Excel spread sheet using ado.net and then creates objects in AD
# uses ADO COM based ... classic ADO to query ansing the dot net framework
# Using ado objects we do not need to have Excel installed
# on the computer.
# We need to use the Jet oledb provider
# and specify extended properties for excel.
# we then need to create an instance of the 
# ADODB.Connection and the ADODB.Command objects.  
# We then use the Execute method to return a RecordSet
# object. 
# The first thing we need to do is use the MoveFirst method to ensure we are at first record
# We use do until to loop through the RecordSet object. 
# Each column is accessed by name using the fields property and the item method. We then use
# the value property to obtain the actual value stored in the field. 
#
# -------------------------------------------------------------------------------------------
Param([switch]$verbose)

Function TestPath($FilePath)
{
 If(Test-Path -path $FilePath)
   {
    if($verbose) { "$filePath found" }
  } #end if
 ELSE
  {
   Write-Host -foregroundcolor red "$filePath not found."
   Exit
  } #end else
} #end TestPath

Function SetConnectionString()
{
 $strFileName = $FilePath
 $strSheetName = 'Excel$'
 $strProvider = "Provider=Microsoft.Jet.OLEDB.4.0"
 $strDataSource = "Data Source = $strFileName"
 $strExtend = "Extended Properties=Excel 8.0"
 $strQuery = "Select * from [$strSheetName]"
 NewAdoConnection
} #end SetConnectionString

Function NewAdoConnection()
{
 $Script:objConn = New-Object -comObject "ADODB.Connection"
 $Command = New-Object -comObject "ADODB.Command"
 $Script:objConn.open("$strProvider;$strDataSource;$strExtend")
 $Command.ActiveConnection = $script:objConn
 $Command.Commandtext = $strQuery
 $Script:RecordSet = $Command.Execute()
} #end NewAdoConnection

Function ReadData()
{
 $Script:RecordSet.MoveFirst()
 Do
 {
  $Script:Name = $Script:RecordSet.Fields.Item("name").Value 
  $Script:Path = $Script:RecordSet.Fields.Item("path").Value
  $Script:Class = $Script:RecordSet.Fields.Item("class").Value
  CreateObject
  $Script:RecordSet.MoveNext()
 }
 Until($Script:recordSet.eof)
} #end ReadData

Function CreateObject()
{
 If($verbose)
  {
   "Creating $Script:Class $Script:Name,$Script:Path"
  } #end if verbose
 $adsi = [adsi]"LDAP://$Script:path"
 $de = $adsi.Create($Script:class,$Script:name)
 $de.SetInfo()
} #end CreateObject

Function CloseAdoConnection()
{  
 $Script:recordSet.close()
 $Script:objConn.close()
}

# *** Entry Point ***
$FilePath = "C:\BestPractices\excel.xls"
TestPath($FilePath)
SetConnectionString
ReadData
CloseAdoConnection
