# ==============================================================================================
# NAME: ModifyProperties_AdoNet.ps1
# 
# AUTHOR: ed wilson , Microsoft 
# DATE  : 9/22/2008
# 
# COMMENT: Queries Excel spread sheet using ado.net
# uses ado.net from .NET framework to query an
# excel spread sheet. using the dot net framework
# ado classes we do not need to have Excel installed
# on the computer.
# just as in classic ado we need to use the Jet oledb provider
# and specify extended properties for excel.
# we then need to create an instance of the 
# System.Data.OleDb.OleDbConnection and 
# System.Data.OleDb.OleDbCommand classes. 
# We then use the ExecuteReader method to return a DataReader
# object. This object is an instance of the System.Data.OleDb.OleDbDataReader class.
# The first thing we need to do with the DataReader is to use
# the read method. We use while to loop through the DataReader.
# Each column can be indexed as seen here: $DataReader[2].Tostring() 
# this picks up the third column. $DataReader[0].Tostring() is first one 
#
# -------------------------------------------------------------------------------------------
Param([switch]$verbose)

Function TestPath($FilePath)
{
 If(Test-Path -path $FilePath)
   {
    Write-Verbose "$filePath found"
  } #end if
 ELSE
  {
   Write-Host -foregroundcolor red "$filePath not found."
   Exit
  } #end else
} #end TestPath

Function SetConnectionString()
{
 $strFileName = $FilePath
 $strSheetName = 'NewUser$'
 $strProvider = "Provider=Microsoft.Jet.OLEDB.4.0"
 $strDataSource = "Data Source = $strFileName"
 $strExtend = "Extended Properties=Excel 8.0"
 $strQuery = "Select * from [$strSheetName]"
 NewAdoConnection
} #end SetConnectionString

Function NewAdoConnection()
{
 $Script:objConn = New-Object System.Data.OleDb.OleDbConnection("$strProvider;$strDataSource;$strExtend")
 $sqlCommand = New-Object System.Data.OleDb.OleDbCommand($strQuery)
 $sqlCommand.Connection = $objConn
 $Script:objConn.open()
 $Script:DataReader = $sqlCommand.ExecuteReader()
} #end NewAdoConnection

Function ReadData()
{
 $columns = $Script:DataReader.FieldCount 
 $aryProperties = [array]::CreateInstance([string],$columns)

 $rowNumber = 0
 While($Script:DataReader.read())
 {
  Write-Verbose "Row number is $rowNumber"
  if($rowNumber -eq 0)
   {
    For($i = 0 ; $i -le $columns -1 ; $i ++)
       {
        Write-Verbose "adding property $i"
        Write-verbose $script:DataReader[$i].ToString()
        $aryProperties[$i] = $script:DataReader[$i].ToString()
       } #end for
   } #end if rownumber
   Write-verbose "printing aryProperties: $aryProperties"
  if($rowNumber -ge 1)
    {
     ModifyObject
    }
  $rowNumber ++
 } #end while
} #end ReadData

Function ModifyObject()
{
 $script:path = "$($script:DataReader[0]),$($script:DataReader[1]),$($script:DataReader[2])"
 Write-Verbose  "Modifying $script:path"
 
For($j = 3 ; $j -le $columns -1 ; $j++)
{
 $adsi = [adsi]"LDAP://$Script:path"
 Write-Verbose "Object: $Script:path"
 write-verbose  "Putting: $($aryProperties[$j]),$($Script:DataReader[$j])"
 if( [string]::IsNullOrEmpty($($script:DataReader[$j])) ) 
    { "missing value: $($aryProperties[$j]) for: $script:path" }
 ELSEif( [string]::IsNullOrEmpty($($aryProperties[$j])) ) 
    { "missing property for $($script:DataReader[$j]) value" }
  ELSE
  {
   $adsi.Put($($aryProperties[$j]),$($Script:DataReader[$j]))
   $adsi.SetInfo()
  }
}
} #end ModifyObject

Function CloseAdoConnection()
{  
 $Script:dataReader.close()
 $Script:objConn.close()
}

# *** Entry Point ***
if($verbose) { $verbosePreference = "continue" }
$FilePath = "C:\BestPractices\ModifyUser.xls"
TestPath($FilePath)
SetConnectionString
ReadData
CloseAdoConnection